addressbook
open | /demo/addressbook.html |
assertTextPresent | Addressbook |
click | clean |
waitForElementNotPresent | //tr[2] |
assertElementNotPresent | //tr[2] |
type | name | Carsten
type | city | Aachen
click | submit |
waitForText | //td[1] | Carsten
assertText | //td[1] | Carsten
assertText | //td[3] | Aachen
type | name | Jonas
type | city | Bern
click | submit |
waitForText | //tr[2]/td[1] | Jonas
assertText | //tr[2]/td[1] | Jonas
assertText | //tr[2]/td[3] | Bern
type | name | Godefroid
type | city | Louvain-la-neuve
click | submit |
waitForText | //tr[3]/td[1] | Godefroid
assertText | //tr[3]/td[1] | Godefroid
assertText | //tr[3]/td[3] | Louvain-la-neuve
click | //tr[3]/td[6]/input[@value='Up'] |
waitForText | //tr[2]/td[1] | Godefroid
assertText | //tr[2]/td[1] | Godefroid
assertText | //tr[2]/td[3] | Louvain-la-neuve
assertText | //tr[3]/td[1] | Jonas
assertText | //tr[3]/td[3] | Bern
click | //input[@value='Down'] |
waitForText | //tr[1]/td[1] | Godefroid
assertText | //tr[1]/td[1] | Godefroid
assertText | //tr[1]/td[3] | Louvain-la-neuve
assertText | //tr[2]/td[1] | Carsten
assertText | //tr[2]/td[3] | Aachen
click | //tr[2]/td[6]/input[@value='Top'] |
waitForText | //tr[1]/td[1] | Carsten
assertText | //tr[1]/td[1] | Carsten
assertText | //tr[1]/td[3] | Aachen
click | //tr[2]/td[6]/input[@value='Bottom'] |
waitForText | //tr[3]/td[1] | Godefroid
assertText | //tr[3]/td[1] | Godefroid
assertText | //tr[3]/td[3] | Louvain-la-neuve
assertText | //tr[2]/td[1] | Jonas
assertText | //tr[2]/td[3] | Bern
assertText | //tr[3]/td[1] | Godefroid
assertText | //tr[3]/td[3] | Louvain-la-neuve
click | //tr[2]/td[6]/input[@value='Remove'] |
waitForText | //tr[1]/td[1] | Carsten
assertText | //tr[1]/td[1] | Carsten
assertText | //tr[1]/td[3] | Aachen
assertText | //tr[2]/td[1] | Godefroid
assertText | //tr[2]/td[3] | Louvain-la-neuve
click | clean |
waitForElementNotPresent | //tr[2] |
assertElementNotPresent | //tr[2] |